=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2007-11-14 08:05:32 +0000
+++ bzrlib/tests/test_transport_implementations.py	2007-11-23 04:56:43 +0000
@@ -45,7 +45,12 @@
                            )
 from bzrlib.osutils import getcwd
 from bzrlib.smart import medium
-from bzrlib.tests import TestCaseInTempDir, TestScenarioApplier, TestSkipped
+from bzrlib.tests import (
+    TestCaseInTempDir,
+    TestScenarioApplier,
+    TestSkipped,
+    TestNotApplicable,
+    )
 from bzrlib.tests.test_transport import TestTransportImplementation
 from bzrlib.transport import (
     ConnectedTransport,
@@ -900,6 +905,20 @@
         self.assertFalse(t.has('adir/bdir'))
         self.assertFalse(t.has('adir/bsubdir'))
 
+    def test_rename_across_subdirs(self):
+        t = self.get_transport()
+        if t.is_readonly():
+            raise TestNotApplicable("transport is readonly")
+        t.mkdir('a')
+        t.mkdir('b')
+        ta = t.clone('a')
+        tb = t.clone('b')
+        ta.put_bytes('f', 'aoeu')
+        ta.rename('f', '../b/f')
+        self.assertTrue(tb.has('f'))
+        self.assertFalse(ta.has('f'))
+        self.assertTrue(t.has('b/f'))
+
     def test_delete_tree(self):
         t = self.get_transport()
 

=== modified file 'bzrlib/transport/memory.py'
--- bzrlib/transport/memory.py	2007-11-03 01:07:33 +0000
+++ bzrlib/transport/memory.py	2007-11-22 09:49:39 +0000
@@ -272,7 +272,7 @@
             if i == '..':
                 if not r:
                     raise ValueError("illegal relpath %r under %r"
-                        % relpath, self._cwd)
+                        % (relpath, self._cwd))
                 r = r[:-1]
             elif i == '.' or i == '':
                 pass

